Index: chrome/browser/ui/browser_tabrestore.h |
diff --git a/chrome/browser/ui/browser_tabrestore.h b/chrome/browser/ui/browser_tabrestore.h |
index 5081c1336f30ebbe5bd05832041183d69e597ebf..52806968ea9df1bd643466a95b3b2e874641d802 100644 |
--- a/chrome/browser/ui/browser_tabrestore.h |
+++ b/chrome/browser/ui/browser_tabrestore.h |
@@ -31,7 +31,8 @@ namespace chrome { |
// the newly created tab is pinned. If |from_last_session| is true, |
// |navigations| are from the previous session. |user_agent_override| contains |
// the string being used as the user agent for all of the tab's navigations when |
-// the regular user agent is overridden. |
+// the regular user agent is overridden. Returns the WebContents of the restored |
+// tab. |
content::WebContents* AddRestoredTab( |
Browser* browser, |
const std::vector<sessions::SerializedNavigationEntry>& navigations, |
@@ -45,8 +46,9 @@ content::WebContents* AddRestoredTab( |
const std::string& user_agent_override); |
// Replaces the state of the currently selected tab with the session |
-// history restored from the SessionRestore system. |
-void ReplaceRestoredTab( |
+// history restored from the SessionRestore system. Returns the WebContents of |
+// the restored tab. |
+content::WebContents* ReplaceRestoredTab( |
Browser* browser, |
const std::vector<sessions::SerializedNavigationEntry>& navigations, |
int selected_navigation, |